pub enum CreationMode {
CreateExclusive,
PurgeAndCreate,
OpenOrCreate,
}Expand description
Describes how new resources like crate::file::File, crate::shared_memory::SharedMemory
or others should be created.
Variants
CreateExclusive
Create resource, if its already existing fail.
PurgeAndCreate
Always remove existing resource and override it with new one
OpenOrCreate
Either open the new resource or create it when it is not existing
Implementations