iceoryx2_bb_threadsafe::trigger_queue

Enum MutexPriorityInheritance

source
#[repr(i32)]
pub enum MutexPriorityInheritance { None = 0, Inherit = 1, Protect = 2, }
Defines how the priority of a mutex owning thread changes when another thread with an higher priority would like to acquire the mutex.

Variants



None = 0

No change in priority



Inherit = 1

The priority of a thread holding the mutex is always promoted to the priority set up in MutexBuilder::priority_ceiling().



Protect = 2

The priority of a thread holding the mutex is promoted to the priority of the highest priority thread waiting for the lock.