pub enum SemaphoreError {
FailedToCreate,
FailedToPost,
FailedToWait,
}Expand description
The SemaphoreError enum is a generalization when one doesn’t require the fine-grained error
handling enums. One can forward SemaphoreError as more generic return value when a method
returns a Semaphore***Error.
On a higher level it is again convertable to crate::Error.
Variants