iceoryx2_bb_threadsafe::trigger_queue

Struct MutexBuilder

source
pub struct MutexBuilder { /* private fields */ }
Creates a Mutex.

Implementations

source

impl MutexBuilder

source

pub fn new() -> MutexBuilder

source

pub fn clock_type(self, clock_type: ClockType) -> MutexBuilder

Defines the ClockType which should be used in Mutex::timed_lock().

source

pub fn is_interprocess_capable(self, value: bool) -> MutexBuilder

Can the same mutex be used from multiple processes.

source

pub fn mutex_type(self, value: MutexType) -> MutexBuilder

MutexType defines the behavior of the mutex.

source

pub fn thread_termination_behavior( self, value: MutexThreadTerminationBehavior, ) -> MutexBuilder

source

pub fn priority_inheritance( self, value: MutexPriorityInheritance, ) -> MutexBuilder

Defines the MutexPriorityInheritance mode.

source

pub fn priority_ceiling(self, value: i32) -> MutexBuilder

Defines to priority to which a thread is promoted when another thread is waiting on the lock and MutexPriorityInheritance::Inherit is set.

source

pub fn create<T>( self, t: T, handle: &MutexHandle<T>, ) -> Result<Mutex<'_, T>, MutexCreationError>
where T: Debug,

Creates a new mutex with a guarded value.