Permission

Struct Permission 

pub struct Permission(/* private fields */);
Defines the permission of a file or directory in a POSIX system.

Implementations

Source

impl Permission

Source

impl Permission

pub fn has(&self, rhs: Permission) -> bool

Returns true when self contains the permissions of the rhs, otherwise false.

pub fn as_mode(&self) -> u32

Converts the permissions into the C type mode_t