TriggerQueue

Struct TriggerQueue 

pub struct TriggerQueue<'a, T: Debug, const CAPACITY: usize> { /* private fields */ }

Implementations

Source

impl<'a, T: Debug, const CAPACITY: usize> TriggerQueue<'a, T, CAPACITY>

pub fn new( mtx_handle: &'a MutexHandle<FixedSizeQueue<T, CAPACITY>>, free_handle: &'a UnnamedSemaphoreHandle, used_handle: &'a UnnamedSemaphoreHandle, ) -> Self

pub fn new_with_custom_clock( mtx_handle: &'a MutexHandle<FixedSizeQueue<T, CAPACITY>>, free_handle: &'a UnnamedSemaphoreHandle, used_handle: &'a UnnamedSemaphoreHandle, clock_type: ClockType, ) -> Self

Creates a new TriggerQueue which uses the user provided clock in TriggerQueue::timed_push() and TriggerQueue::timed_pop().

pub fn try_push(&self, value: T) -> bool

Tries to push a value into the queue. When the queue is full it returns false, otherwise true.

pub fn timed_push(&self, value: T, timeout: Duration) -> bool

Tries to push a value into the queue until the timeout is reached. If the sample was pushed into the queue it returns true, otherwise false.

pub fn blocking_push(&self, value: T)

Blocks the process until the value could be pushed into the queue.

pub fn try_pop(&self) -> Option<T>

Tries to pop a value out of the queue. If the queue was empty it returns None otherwise the value packed inside the Option.

pub fn timed_pop(&self, timeout: Duration) -> Option<T>

Tries to pop a value out of the queue until the timeout is reached. If a value could not be acquired it returns None.

pub fn blocking_pop(&self) -> T

Blocks until a value could be acquired from the queue.

pub fn clear(&self)

Empties the queue.

pub fn capacity(&self) -> usize

Returns the capacity of the queue.

pub fn len(&self) -> usize

Returns the amount of values stored inside the queue

pub fn is_full(&self) -> bool

Returns true if the queue is full, otherwise false

pub fn is_empty(&self) -> bool

Returns true if the queue is empty, otherwise false