pub trait IpcCapable<'a, T>: Sized + IpcConstructible<'a, T>where
T: Handle,{
// Required method
fn is_interprocess_capable(&self) -> bool;
// Provided method
unsafe fn from_ipc_handle(handle: &'a T) -> Self { ... }
}Expand description
Represents struct that can be configured for inter-process use.
Required Methods
Sourcefn is_interprocess_capable(&self) -> bool
fn is_interprocess_capable(&self) -> bool
Returns true if the object is interprocess capable, otherwise false
Provided Methods
Sourceunsafe fn from_ipc_handle(handle: &'a T) -> Self
unsafe fn from_ipc_handle(handle: &'a T) -> Self
Creates an IPC Capable object from its handle.
Safety
- The handle must be initialized
- The handle must be ipc capable, see
Handle::is_inter_process_capable(). - The handle must not be cleaned up while it is used by the object
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.