iceoryx2_bb_threadsafe::trigger_queue

Struct Permission

source
pub struct Permission(/* private fields */);
Defines the permission of a file or directory in a POSIX system.

Implementations

source

impl Permission

source

impl Permission

source

pub const fn empty() -> Permission

Get a flags value with all bits unset.

source

pub const fn all() -> Permission

Get a flags value with all known bits set.

source

pub const fn bits(&self) -> u32

Get the underlying bits value.

The returned value is exactly the bits set in this flags value.

source

pub const fn from_bits(bits: u32) -> Option<Permission>

Convert from a bits value.

This method will return None if any unknown bits are set.

source

pub const fn from_bits_truncate(bits: u32) -> Permission

Convert from a bits value, unsetting any unknown bits.

source

pub const fn from_bits_retain(bits: u32) -> Permission

Convert from a bits value exactly.

source

pub fn from_name(name: &str) -> Option<Permission>

Get a flags value with the bits of a flag with the given name set.

This method will return None if name is empty or doesn’t correspond to any named flag.

source

pub const fn is_empty(&self) -> bool

Whether all bits in this flags value are unset.

source

pub const fn is_all(&self) -> bool

Whether all known bits in this flags value are set.

source

pub const fn intersects(&self, other: Permission) -> bool

Whether any set bits in a source flags value are also set in a target flags value.

source

pub const fn contains(&self, other: Permission) -> bool

Whether all set bits in a source flags value are also set in a target flags value.

source

pub fn insert(&mut self, other: Permission)

The bitwise or (|) of the bits in two flags values.

source

pub fn remove(&mut self, other: Permission)

The intersection of a source flags value with the complement of a target flags value (&!).

This method is not equivalent to self & !other when other has unknown bits set. remove won’t truncate other, but the ! operator will.

source

pub fn toggle(&mut self, other: Permission)

The bitwise exclusive-or (^) of the bits in two flags values.

source

pub fn set(&mut self, other: Permission, value: bool)

Call insert when value is true or remove when value is false.

source

pub const fn intersection(self, other: Permission) -> Permission

The bitwise and (&) of the bits in two flags values.

source

pub const fn union(self, other: Permission) -> Permission

The bitwise or (|) of the bits in two flags values.

source

pub const fn difference(self, other: Permission) -> Permission

The intersection of a source flags value with the complement of a target flags value (&!).

This method is not equivalent to self & !other when other has unknown bits set. difference won’t truncate other, but the ! operator will.

source

pub const fn symmetric_difference(self, other: Permission) -> Permission

The bitwise exclusive-or (^) of the bits in two flags values.

source

pub const fn complement(self) -> Permission

The bitwise negation (!) of the bits in a flags value, truncating the result.

source

impl Permission

source

pub const fn iter(&self) -> Iter<Permission>

Yield a set of contained flags values.

Each yielded flags value will correspond to a defined named flag. Any unknown bits will be yielded together as a final flags value.

source

pub const fn iter_names(&self) -> IterNames<Permission>

Yield a set of contained named flags values.

This method is like iter, except only yields bits in contained named flags. Any unknown bits, or bits not corresponding to a contained flag will not be yielded.

source

impl Permission

source

impl Permission

source

pub fn has(&self, rhs: Permission) -> bool

Returns true when self contains the permissions of the rhs, otherwise false.

source

pub fn as_mode(&self) -> u32

Converts the permissions into the C type mode_t