pub struct Permission(/* private fields */);Expand description
Defines the permission of a file or directory in a POSIX system.
Implementations
sourceimpl Permission
impl Permission
pub const OWNER_READ: Permission = _
pub const OWNER_WRITE: Permission = _
pub const OWNER_EXEC: Permission = _
pub const OWNER_ALL: Permission = _
pub const GROUP_READ: Permission = _
pub const GROUP_WRITE: Permission = _
pub const GROUP_EXEC: Permission = _
pub const GROUP_ALL: Permission = _
pub const OTHERS_READ: Permission = _
pub const OTHERS_WRITE: Permission = _
pub const OTHERS_EXEC: Permission = _
pub const OTHERS_ALL: Permission = _
pub const ALL: Permission = _
pub const SET_UID: Permission = _
pub const SET_GID: Permission = _
pub const STICKY_BIT: Permission = _
pub const MASK: Permission = _
pub const UNKNOWN: Permission = _
sourceimpl Permission
impl Permission
sourcepub const fn empty() -> Permission
pub const fn empty() -> Permission
Get a flags value with all bits unset.
sourcepub const fn all() -> Permission
pub const fn all() -> Permission
Get a flags value with all known bits set.
sourcepub const fn bits(&self) -> u32
pub const fn bits(&self) -> u32
Get the underlying bits value.
The returned value is exactly the bits set in this flags value.
sourcepub const fn from_bits(bits: u32) -> Option<Permission>
pub const fn from_bits(bits: u32) -> Option<Permission>
Convert from a bits value.
This method will return None if any unknown bits are set.
sourcepub const fn from_bits_truncate(bits: u32) -> Permission
pub const fn from_bits_truncate(bits: u32) -> Permission
Convert from a bits value, unsetting any unknown bits.
sourcepub const fn from_bits_retain(bits: u32) -> Permission
pub const fn from_bits_retain(bits: u32) -> Permission
Convert from a bits value exactly.
sourcepub fn from_name(name: &str) -> Option<Permission>
pub fn from_name(name: &str) -> Option<Permission>
Get a flags value with the bits of a flag with the given name set.
This method will return None if name is empty or doesn’t
correspond to any named flag.
sourcepub const fn intersects(&self, other: Permission) -> bool
pub const fn intersects(&self, other: Permission) -> bool
Whether any set bits in a source flags value are also set in a target flags value.
sourcepub const fn contains(&self, other: Permission) -> bool
pub const fn contains(&self, other: Permission) -> bool
Whether all set bits in a source flags value are also set in a target flags value.
sourcepub fn insert(&mut self, other: Permission)
pub fn insert(&mut self, other: Permission)
The bitwise or (|) of the bits in two flags values.
sourcepub fn remove(&mut self, other: Permission)
pub fn remove(&mut self, other: Permission)
The intersection of a source flags value with the complement of a target flags value (&!).
This method is not equivalent to self & !other when other has unknown bits set.
remove won’t truncate other, but the ! operator will.
sourcepub fn toggle(&mut self, other: Permission)
pub fn toggle(&mut self, other: Permission)
The bitwise exclusive-or (^) of the bits in two flags values.
sourcepub fn set(&mut self, other: Permission, value: bool)
pub fn set(&mut self, other: Permission, value: bool)
Call insert when value is true or remove when value is false.
sourcepub const fn intersection(self, other: Permission) -> Permission
pub const fn intersection(self, other: Permission) -> Permission
The bitwise and (&) of the bits in two flags values.
sourcepub const fn union(self, other: Permission) -> Permission
pub const fn union(self, other: Permission) -> Permission
The bitwise or (|) of the bits in two flags values.
sourcepub const fn difference(self, other: Permission) -> Permission
pub const fn difference(self, other: Permission) -> Permission
The intersection of a source flags value with the complement of a target flags value (&!).
This method is not equivalent to self & !other when other has unknown bits set.
difference won’t truncate other, but the ! operator will.
sourcepub const fn symmetric_difference(self, other: Permission) -> Permission
pub const fn symmetric_difference(self, other: Permission) -> Permission
The bitwise exclusive-or (^) of the bits in two flags values.
sourcepub const fn complement(self) -> Permission
pub const fn complement(self) -> Permission
The bitwise negation (!) of the bits in a flags value, truncating the result.
sourceimpl Permission
impl Permission
sourcepub const fn iter(&self) -> Iter<Permission>
pub const fn iter(&self) -> Iter<Permission>
Yield a set of contained flags values.
Each yielded flags value will correspond to a defined named flag. Any unknown bits will be yielded together as a final flags value.
sourcepub const fn iter_names(&self) -> IterNames<Permission>
pub const fn iter_names(&self) -> IterNames<Permission>
Yield a set of contained named flags values.
This method is like iter, except only yields bits in contained named flags.
Any unknown bits, or bits not corresponding to a contained flag will not be yielded.
sourceimpl Permission
impl Permission
pub fn none() -> Permission
sourceimpl Permission
impl Permission