Struct iceoryx2_bb_threadsafe::trigger_queue::Permission
source · pub struct Permission { /* private fields */ }Expand description
Defines the permission of a file or directory in a POSIX system.
Implementations
sourceimpl Permission
impl Permission
pub const OWNER_READ: Permission = _
pub const OWNER_WRITE: Permission = _
pub const OWNER_EXEC: Permission = _
pub const OWNER_ALL: Permission = _
pub const GROUP_READ: Permission = _
pub const GROUP_WRITE: Permission = _
pub const GROUP_EXEC: Permission = _
pub const GROUP_ALL: Permission = _
pub const OTHERS_READ: Permission = _
pub const OTHERS_WRITE: Permission = _
pub const OTHERS_EXEC: Permission = _
pub const OTHERS_ALL: Permission = _
pub const ALL: Permission = _
pub const SET_UID: Permission = _
pub const SET_GID: Permission = _
pub const STICKY_BIT: Permission = _
pub const MASK: Permission = _
pub const UNKNOWN: Permission = _
sourcepub const fn empty() -> Permission
pub const fn empty() -> Permission
Returns an empty set of flags.
sourcepub const fn all() -> Permission
pub const fn all() -> Permission
Returns the set containing all flags.
sourcepub const fn from_bits(bits: u32) -> Option<Permission>
pub const fn from_bits(bits: u32) -> Option<Permission>
Convert from underlying bit representation, unless that representation contains bits that do not correspond to a flag.
sourcepub const fn from_bits_truncate(bits: u32) -> Permission
pub const fn from_bits_truncate(bits: u32) -> Permission
Convert from underlying bit representation, dropping any bits that do not correspond to flags.
sourcepub const unsafe fn from_bits_unchecked(bits: u32) -> Permission
pub const unsafe fn from_bits_unchecked(bits: u32) -> Permission
Convert from underlying bit representation, preserving all bits (even those not corresponding to a defined flag).
Safety
The caller of the bitflags! macro can chose to allow or
disallow extra bits for their bitflags type.
The caller of from_bits_unchecked() has to ensure that
all bits correspond to a defined flag or that extra bits
are valid for this bitflags type.
sourcepub const fn intersects(&self, other: Permission) -> bool
pub const fn intersects(&self, other: Permission) -> bool
Returns true if there are flags common to both self and other.
sourcepub const fn contains(&self, other: Permission) -> bool
pub const fn contains(&self, other: Permission) -> bool
Returns true if all of the flags in other are contained within self.
sourcepub fn insert(&mut self, other: Permission)
pub fn insert(&mut self, other: Permission)
Inserts the specified flags in-place.
sourcepub fn remove(&mut self, other: Permission)
pub fn remove(&mut self, other: Permission)
Removes the specified flags in-place.
sourcepub fn toggle(&mut self, other: Permission)
pub fn toggle(&mut self, other: Permission)
Toggles the specified flags in-place.
sourcepub fn set(&mut self, other: Permission, value: bool)
pub fn set(&mut self, other: Permission, value: bool)
Inserts or removes the specified flags depending on the passed value.
sourcepub const fn intersection(self, other: Permission) -> Permission
pub const fn intersection(self, other: Permission) -> Permission
Returns the intersection between the flags in self and
other.
Specifically, the returned set contains only the flags which are
present in both self and other.
This is equivalent to using the & operator (e.g.
ops::BitAnd), as in flags & other.
sourcepub const fn union(self, other: Permission) -> Permission
pub const fn union(self, other: Permission) -> Permission
Returns the union of between the flags in self and other.
Specifically, the returned set contains all flags which are
present in either self or other, including any which are
present in both (see Self::symmetric_difference if that
is undesirable).
This is equivalent to using the | operator (e.g.
ops::BitOr), as in flags | other.
sourcepub const fn difference(self, other: Permission) -> Permission
pub const fn difference(self, other: Permission) -> Permission
Returns the difference between the flags in self and other.
Specifically, the returned set contains all flags present in
self, except for the ones present in other.
It is also conceptually equivalent to the “bit-clear” operation:
flags & !other (and this syntax is also supported).
This is equivalent to using the - operator (e.g.
ops::Sub), as in flags - other.
sourcepub const fn symmetric_difference(self, other: Permission) -> Permission
pub const fn symmetric_difference(self, other: Permission) -> Permission
Returns the symmetric difference between the flags
in self and other.
Specifically, the returned set contains the flags present which
are present in self or other, but that are not present in
both. Equivalently, it contains the flags present in exactly
one of the sets self and other.
This is equivalent to using the ^ operator (e.g.
ops::BitXor), as in flags ^ other.
sourcepub const fn complement(self) -> Permission
pub const fn complement(self) -> Permission
Returns the complement of this set of flags.
Specifically, the returned set contains all the flags which are
not set in self, but which are allowed for this type.
Alternatively, it can be thought of as the set difference
between Self::all() and self (e.g. Self::all() - self)
This is equivalent to using the ! operator (e.g.
ops::Not), as in !flags.
sourceimpl Permission
impl Permission
pub fn none() -> Permission
sourceimpl Permission
impl Permission